﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

using MvcApplication1.Models;

namespace MvcApplication1.Controllers
{
    [HandleError(Order = 2)]
    //[Authorize(Users="*")]
    public class ProductController : Controller
    {
        private NorthwindAccessConsolidator nwa = new NorthwindAccessConsolidator();

        //
        // GET: /Product/

        [HandleError(View = "NoSuchRecordError")]
        public ActionResult Index()
        {
            return View(nwa.ListProducts());
        }

        //
        // GET: /Product/Details/5
        [HandleError(View = "NoSuchRecordError", ExceptionType = typeof(NoSuchRecordException))]
        public ActionResult Details(int id)
        {
            Products prod = nwa.GetProduct(id);

            if (prod == null)
            {
                throw new NoSuchRecordException();
            }
            else
            {
                return View(prod);
            }
        }

        //
        // GET: /Product/Create

        public ActionResult Create()
        {
            return View(new Products());
        }

        //
        // POST: /Product/Create

        [HttpPost]
        public ActionResult Create(Products prod)
        {
            try
            {
                // TODO: Add insert logic here
                nwa.StoreNewProduct(prod);
                return RedirectToAction("Index");
            }
            catch
            {
                return View();
            }
        }

        //
        // GET: /Product/Edit/5

        public ActionResult Edit(int id)
        {
            return View(nwa.GetProduct(id));
        }

        //
        // POST: /Product/Edit/5

        [HttpPost]
        public ActionResult Edit(int id, FormCollection collection)
        {
            try
            {
                Products prod = nwa.GetProduct(id);

                if (prod != null)
                {
                    UpdateModel(prod);
                    nwa.SaveChanges();
                    return RedirectToAction("Index");
                }
                else
                {
                    throw new NoSuchRecordException();
                }
            }
            catch
            {
                return View();
            }
        }

        //
        // GET: /Product/Delete/5
        //[Authorize(Users="Jan")]
        public ActionResult Delete(int id)
        {
            return View(nwa.GetProduct(id));
        }

        //
        // POST: /Product/Delete/5

        [HttpPost]
        public ActionResult Delete(int id, FormCollection collection)
        {
            try
            {
                nwa.DeleteProduct(id);
                return RedirectToAction("Index");
            }
            catch
            {
                return View();
            }
        }

        class NoSuchRecordException : Exception
        {

        }

        class NorthwindAccessConsolidator
        {
            private NorthwindEntities db = new NorthwindEntities();

            public IEnumerable<Products> ListProducts()
            {
                return db.Products;
            }

            public Products GetProduct(int id)
            {
                IEnumerable<Products> data = db.Products
                    .Where(e => e.ProductID == id)
                    .Select(e => e);
                return data.Count() > 0 ? data.Single() : null;
            }

            public void DeleteProduct(int id)
            {
                Products prod = GetProduct(id);
                if (prod != null)
                {
                    IEnumerable<Order_Details> ods =
                        db.Order_Details
                        .Where(e => e.ProductID == id)
                        .Select(e => e);
                    foreach (Order_Details od in ods)
                    {
                        db.Order_Details.DeleteObject(od);
                    }

                    db.Products.DeleteObject(prod);
                    SaveChanges();
                }
            }

            public void StoreNewProduct(Products prod)
            {
                db.Products.AddObject(prod);
                SaveChanges();
            }

            public void SaveChanges()
            {
                db.SaveChanges();
            }
        }
    }
}
