﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

using System.Data.SqlClient;
using System.Data;
using System.Diagnostics;

public class OfflineData
{
    public DataSet DemoOfflineData()
    {
        Debugger.Break();

        //Create two datatables:
        DataTable dtEmps = CreateDataTableEmployees();
        DataTable dtOrders = CreateDataTableOrders();

        //Create DataSet:
        DataSet ds = new DataSet("EmpsAndOrders");
        ds.Tables.Add(dtEmps);
        ds.Tables.Add(dtOrders);
        
        //Create Relation:
        CreateRelation(dtEmps, dtOrders, ds);

        //Create foreign key constraint (but already done by creating relation):
        CreateForeignKey(dtEmps, dtOrders);

        //Create Unique constraint:
        CreateUniqueConstraint(dtEmps);

        //Fill with data:
        FillDataTables(dtEmps, dtOrders);

        //Create Dataview:
        FilterEmployeesWithoutEmail(dtEmps);
        
        //Return the DataSet:
        return ds;
    }

    private DataTable CreateDataTableEmployees()
    {
        DataTable dtEmps = new DataTable("Employees");

        dtEmps.Columns.Add("ID", typeof(Int32));
        dtEmps.Columns.Add("FirstName", typeof(string));
        dtEmps.Columns.Add("LastName", typeof(string));
        dtEmps.Columns.Add("Email", typeof(string));

        dtEmps.PrimaryKey = new DataColumn[1] { dtEmps.Columns["ID"] };

        return dtEmps;
    }

    private DataTable CreateDataTableOrders()
    {
        DataTable dtOrders = new DataTable("Orders");

        dtOrders.Columns.Add("ID", typeof(Int32));
        dtOrders.Columns.Add("EmployeeID", typeof(Int32));
        dtOrders.Columns.Add("OrderDate", typeof(DateTime));

        dtOrders.PrimaryKey = new DataColumn[1] { dtOrders.Columns["ID"] };

        return dtOrders;
    }

    private  void CreateRelation(DataTable dtEmps, DataTable dtOrders, DataSet ds)
    {
        DataColumn parent = dtEmps.Columns["ID"];
        DataColumn child = dtOrders.Columns["EmployeeID"];
        DataRelation drEmpOrder = new DataRelation("EmpOrder", parent, child);
        ds.Relations.Add(drEmpOrder);
    }

    private  void CreateUniqueConstraint(DataTable dtEmps)
    {
        DataColumn colEmail = dtEmps.Columns["Email"];
        UniqueConstraint UConstr = new UniqueConstraint(colEmail);
        dtEmps.Constraints.Add(UConstr);

        //Or, simpler: colEmail.Unique = true;
    }

    private  void CreateForeignKey(DataTable dtEmps, DataTable dtOrders)
    {
        //DataColumn colID = dtEmps.Columns["ID"];
        //DataColumn colEmpID = dtOrders.Columns["EmployeeID"];
        //ForeignKeyConstraint FKConstr = new ForeignKeyConstraint(colID, colEmpID);
        //dtOrders.Constraints.Add(FKConstr);
    }

    private void FillDataTables(DataTable Employees, DataTable Orders)
    {
        //Add some employees:
        Employees.Rows.Add(new object[4] { 1,  "Donald", "Duck", "donald@duck.com" });
        Employees.Rows.Add(new object[4] { 2, "Lucky", "Luke", "lucky@luke.com" });
        Employees.Rows.Add(new object[3] { 3, "Mickey", "Mouse" });

        //Add some orders:
        Orders.Rows.Add(new object[3] { 1, "1", new DateTime(2008, 12, 2) });
        Orders.Rows.Add(new object[3] { 2, "1", new DateTime(2009, 1, 22) });
        Orders.Rows.Add(new object[3] { 3, "1", new DateTime(2009, 7, 5) });

        Orders.Rows.Add(new object[3] { 4, "2", new DateTime(2009, 4, 30) });
        Orders.Rows.Add(new object[3] { 5, "2", new DateTime(2009, 9, 5) });

        //Read column value:
        //object oEmail = Employees.Rows[1][3]; //Returns: lucky@luke.com
    }

    private void FilterEmployeesWithoutEmail(DataTable Employees)
    {
        DataView dv = new DataView(Employees);
        dv.RowFilter = "Email is null";
        dv.Sort = "LastName ASC, FirstName";

        if (dv.Count > 0)
        {
            foreach (DataRowView row in dv)
            {
                object oName = row[1];
            }
        }
        
    }
}
