﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.IO;

public partial class ObjectDataSource : System.Web.UI.Page
{

    string[] names = { "Smith", "Johnsson", "O'Reilley", 
                       "Blatter", "Enquist", "Oybek", 
                       "Vlug", "Störig", "Michener" };

    
    protected void cmdSimpleLinq_Click(object sender, EventArgs e)
    {
        //Very basic Linq:
        lbSimpleLinq.Items.Add("** BASIC DEMO:");


        IEnumerable<string> query1 = from s in names
                                     where s.Length == 5
                                     orderby s
                                     select s.ToUpper();


        //OR:
        //IEnumerable<string> query1 = names
        //                .Where(s => s.Length == 5)
        //                .OrderBy(s => s)
        //                .Select(s => s.ToUpper());

        foreach (string item in query1)
            lbSimpleLinq.Items.Add(item);

    }

    protected void cmdSimpleLinq2_Click(object sender, EventArgs e)
    {
        //More complex expression:
        lbSimpleLinq2.Items.Add("** MORE COMPLEX DEMO:");

        //Filter with where (Simple):
        IEnumerable<String> query2 = from n in names
                                     where n.Contains("MI")
                                     orderby n.Length
                                     select n.ToUpper();

        foreach (string item in query2)
            lbSimpleLinq2.Items.Add(item);

        //Filter with where (More complex):
        IEnumerable<String> query3 = Enumerable.Where(
            names, name => name.Contains("Mi"))
            .OrderBy(name => name.Length).Select(name => name.ToUpper());

        lbSimpleLinq2.Items.Add("** AFTER WHERE:");
        foreach (string item in query3)
            lbSimpleLinq2.Items.Add(item);

    }

    protected void cmdFileSystem_Click(object sender, EventArgs e)
    {
        lbFileSystem.Items.Add("*** FILE SYSTEM:");

        string sPath = Server.MapPath("~");
        DirectoryInfo dirInfo = new DirectoryInfo(sPath);

        var query =
            from f in dirInfo.GetFiles()
            where f.Length > 1000
            orderby f.Length descending
            select f;

        foreach (FileInfo item in query)
            lbFileSystem.Items.Add(item.ToString());

        lbFileSystem.Rows = (lbFileSystem.Items.Count > 4 && lbFileSystem.Items.Count < 10 ? lbFileSystem.Items.Count : 10);
        
    }
    protected void cmdFindInString_Click(object sender, EventArgs e)
    {
        lbFindInString.Items.Add("*** STRING QUERY:");

        string aString = "ABCDE99F-J74-12-89A";
        lbFindInString.Items.Add("**STRING IS: " + aString);

        // Select only those characters that are numbers
        IEnumerable<char> stringQuery =
          from ch in aString
          where Char.IsDigit(ch)
          select ch;

        foreach (char item in stringQuery)
            lbFindInString.Items.Add(item.ToString());

        lbFindInString.Rows = (lbFindInString.Items.Count > 4 && lbFindInString.Items.Count < 10 ? lbFindInString.Items.Count : 10);


    }
}

