﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

using System.Data;
using System.Data.SqlClient;

/// <summary>
/// Summary description for Employee
/// </summary>
public class Product
{
  
    public static DataTable SelectAll()
    {
        string sql = "SELECT ProductID, ProductName, UnitPrice, Discontinued, p.CategoryID, c.CategoryName FROM Products p" +
            " INNER JOIN Categories c ON p.CategoryID = c.CategoryID";
        DataTable dt = new DataTable();
        using (SqlConnection cn = CData.GetConnection())
        {
            SqlDataAdapter da = new SqlDataAdapter(sql, cn);
            da.Fill(dt);

            return dt;
        }
    }

    public static DataTable SelectCategories()
    {
        string sql = "SELECT CategoryID, CategoryName FROM Categories";
        DataTable dt = new DataTable();
        using (SqlConnection cn = CData.GetConnection())
        {
            SqlDataAdapter da = new SqlDataAdapter(sql, cn);
            da.Fill(dt);

            return dt;
        }
    }

    public static Product Select(int ID)
    {

        string sql = "SELECT ProductID, ProductName, UnitPrice, Discontinued, CategoryID FROM Products WHERE ProductID=@pmProductID";
        Product prod = null;
        using (SqlConnection cn = CData.GetConnection())
        {
            SqlCommand com = new SqlCommand(sql, cn);
            com.Parameters.AddWithValue("@pmProductID", ID);
            cn.Open();
            SqlDataReader reader = com.ExecuteReader();

            if (reader.Read())
            {
                prod = new Product();

                prod.ProductID = reader.GetInt32(0);
                prod.ProductName = reader.GetString(1);
                prod.UnitPrice = (reader.IsDBNull(2) ? 0.0M : reader.GetDecimal(2));
                prod.Discontinued = reader.GetBoolean(3);
                prod.CategoryID = reader.GetInt32(4);
            }
            return prod;
        }
    }

    public static void Insert(Product prod)
    {
        string sql = "INSERT INTO Products(ProductName, UnitPrice, Discontinued, CategoryID) VALUES (@pmProductName, @pmUnitPrice, @Discontinued, @CategoryID)";

        using (SqlConnection cn = CData.GetConnection())
        {
            SqlCommand com = new SqlCommand(sql, cn);
            com.Parameters.AddWithValue("@pmProductName", prod.ProductName);
            com.Parameters.AddWithValue("@pmUnitPrice", prod.UnitPrice);
            com.Parameters.AddWithValue("@Discontinued", prod.Discontinued);
            com.Parameters.AddWithValue("@CategoryID", prod.CategoryID);
            
            cn.Open();
            int iRecsAffected = com.ExecuteNonQuery();
        }
    }

    public static void Update(Product prod)
    {
        string sql = "UPDATE Products SET ProductName = @pmProductName, UnitPrice = @pmUnitPrice, " +
            "Discontinued = @Discontinued, CategoryID = @pmCategoryID WHERE ProductID = @pmProductID";

        using (SqlConnection cn = CData.GetConnection())
        {
            SqlCommand com = new SqlCommand(sql, cn);
            com.Parameters.AddWithValue("@pmProductName", prod.ProductName);
            com.Parameters.AddWithValue("@pmUnitPrice", prod.UnitPrice);
            com.Parameters.AddWithValue("@Discontinued", prod.Discontinued);
            com.Parameters.AddWithValue("@pmProductID", prod.ProductID);
            com.Parameters.AddWithValue("@pmCategoryID", prod.CategoryID);

            cn.Open();
            int iRecsAffected = com.ExecuteNonQuery();
        }
    }

    public static void Delete(Product prod)
    {
        string sql = "DELETE Products WHERE ProductID = @pmProductID";

        using (SqlConnection cn = CData.GetConnection())
        {
            SqlCommand com = new SqlCommand(sql, cn);
            com.Parameters.AddWithValue("@pmProductID", prod.ProductID);

            cn.Open();
            int iRecsAffected = com.ExecuteNonQuery();
        }
    }

    #region Properties

    public int ProductID { get; set; }
    public string ProductName { get; set; }
    public decimal UnitPrice { get; set; }
    public bool Discontinued { get; set; }
    public int CategoryID { get; set; }

    #endregion


}
