﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using System.Drawing;
using System.IO;

namespace FileUploadControl
{
    [ToolboxBitmap(typeof(FileUploadEx), "fileUpload.bmp")] //Requires System.Drawing
    [DefaultProperty("SaveFolder")]
    [ToolboxData("<{0}:FileUploadEx runat=server></{0}:FileUploadEx>")]
    public class FileUploadEx : CompositeControl //WebControl
    {
        #region Properties

        private HttpPostedFile mFilePost;
        private string msSaveFolder;

        [Category("Appearance")]
        [DefaultValue("")]
        public bool GotFile
        {
            get
            {
                if (ViewState["GotFile"] == null)
                    return false;
                else
                    return Convert.ToBoolean(ViewState["GotFile"]);
            }
            private set
            {
                ViewState["GotFile"] = value;
            }
        }

        public string FileExtension
        {
            get
            {
                if (ViewState["FileExtension"] == null)
                    return string.Empty;
                else
                    return Convert.ToString(ViewState["FileExtension"]);
            }
            private set
            {
                ViewState["FileExtension"] = value;
            }
        }

        public HttpPostedFile FilePost
        {
            get
            {
                if (ViewState["FilePost"] == null)
                    return null;
                else
                    return ViewState["FilePost"] as HttpPostedFile;
            }
            private set
            {
                ViewState["FilePost"] = value;
            }
        }

        [Category("UploadProperties")]
        [DefaultValue("FileUploadEx")]
        [Description("ValidationGroup. Set if part of form")]
        public string ValidationGroup
        {
            get
            {
                if (ViewState["ValidationGroup"] == null)
                    return "";
                else
                    return Convert.ToString(ViewState["ValidationGroup"]);
            }
            set
            {
                ViewState["ValidationGroup"] = value;
            }
        }

        [Category("UploadProperties")]
        [DefaultValue("jpg;jpeg;gif;bmp;png")]
        [Description("Allowed file extensions, seperated by ';' and without '.'")]
        public string FileTypeRange
        {
            get
            {
                if (ViewState["FileTypeRange"] == null)
                    return "jpg;jpeg;gif;bmp;png";
                else
                    return Convert.ToString(ViewState["FileTypeRange"]);
            }
            set
            {
                ViewState["FileTypeRange"] = value;
            }
        }

        [Bindable(true)]
        [Category("UploadProperties")]
        [DefaultValue("0")]
        [Description("The minimum width of an image in pixels. Only considered if 'IsImage=true'")]
        public int MinWidth
        {
            get
            {
                if (ViewState["MinWidth"] == null)
                    return 0;
                else
                    return Convert.ToInt32(ViewState["MinWidth"]);
            }
            set
            {
                ViewState["MinWidth"] = value;
            }
        }

        [Category("UploadProperties")]
        [DefaultValue("")]
        public string SaveFolder
        {
            get { return msSaveFolder; }
            set { msSaveFolder = value; }
        }

        [Category("UploadProperties")]
        [DefaultValue("false")]
        public bool IsImage
        {
            get
            {
                if (ViewState["IsImage"] == null)
                    return false;
                else
                    return Convert.ToBoolean(ViewState["IsImage"]);
            }
            set
            {
                ViewState["IsImage"] = value;
            }
        }

        #endregion

        #region Control Declarations

        FileUpload fuFileUpload = new FileUpload();
        CustomValidator valCustomValidator = new CustomValidator();
        LinkButton lbUpload = new LinkButton();

        #endregion

        //Create, not in template:
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);
            valCustomValidator.ServerValidate += new ServerValidateEventHandler(valCustomValidator_ServerValidate);
            lbUpload.Click += new EventHandler(lbUpload_Click);
            valCustomValidator.ValidationGroup = ValidationGroup;
        }

        #region Control Events

        void valCustomValidator_ServerValidate(object source, ServerValidateEventArgs args)
        {
            if (fuFileUpload.HasFile)
            {
                GotFile = true;
                FileExtension = Path.GetExtension(fuFileUpload.PostedFile.FileName).ToLower();
                if (FileExtension.StartsWith(".")) FileExtension = FileExtension.Substring(1);
                mFilePost = fuFileUpload.PostedFile;

                string[] AllowedExtensions = FileTypeRange.Split(';');

                if(!AllowedExtensions.Contains(FileExtension))
                {
                    args.IsValid = false;
                    valCustomValidator.Text = "Dit type bestand is niet toegestaan!";
                    return; //Stop the function
                }

                if (MinWidth > 0 && IsImage)
                {
                    System.Drawing.Image imgTemp = System.Drawing.Image.FromStream(fuFileUpload.PostedFile.InputStream);
                    if (imgTemp.PhysicalDimension.Width < MinWidth)
                    {
                        args.IsValid = false;
                        valCustomValidator.Text = string.Format("Uw afbeelding moet minimaal {0} pixels breed zijn!", MinWidth);
                        return;
                    }
                }
            }
        }

        void lbUpload_Click(object sender, EventArgs e)
        {
            if (Page.IsValid)
            {
                if (this.GotFile)
                {
                    if (!Directory.Exists(SaveFolder))
                    {
                        throw new DirectoryNotFoundException();
                    }
                    string sFileName = string.Format(@"{0}\{1}.{2}", SaveFolder, Guid.NewGuid(), this.FileExtension);
                    fuFileUpload.SaveAs(sFileName);
                }
            }
        }

        #endregion

        //Not in template. Create.
        protected override void CreateChildControls()
        {
            base.CreateChildControls();

            Panel pnlContainer = new Panel();

            fuFileUpload.ID = "FileUpload1";
            pnlContainer.Controls.Add(fuFileUpload);

            pnlContainer.Controls.Add(new LiteralControl("<br/>"));

            valCustomValidator.ID = "valCustomValidator";
            valCustomValidator.ErrorMessage = "Error";
            valCustomValidator.Text = "Text";
            pnlContainer.Controls.Add(valCustomValidator);

            pnlContainer.Controls.Add(new LiteralControl("<br/>"));

            lbUpload.Text = "Upload";
            pnlContainer.Controls.Add(lbUpload);

            pnlContainer.Controls.Add(new LiteralControl("<br/>"));

            this.Controls.Add(pnlContainer);

            //this.ChildControlsCreated = true;   //Intellisense says this property is read-only!
        }


        //Remove this: else controls will not be shown!!

        //protected override void RenderContents(HtmlTextWriter output)
        //{
        //    //output.Write(Text);
        //}
    }


}
