﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Diagnostics;

public partial class PerformanceCounters : System.Web.UI.Page
{


    protected void lbWorkWithCustomCounter_Click(object sender, EventArgs e)
    {
        //Set:
        PerformanceCounter pc = new PerformanceCounter("My Custom Counters", "App Usage", false);
        pc.Increment();

        //Get:
        lblCounterValue.Text = pc.RawValue.ToString();
    }


    protected void lbCreateCustom_Click(object sender, EventArgs e)
    {
        if (!PerformanceCounterCategory.Exists("My Custom Counters"))
        {
            CounterCreationDataCollection counters = new CounterCreationDataCollection();

            counters.Add(new CounterCreationData("App Usage", "Sales menu clicks", PerformanceCounterType.NumberOfItems32));
            counters.Add(new CounterCreationData("Help Usage", "Help menu clicks", PerformanceCounterType.NumberOfItems32));
            counters.Add(new CounterCreationData("Printer Usage", "Print menu clicks", PerformanceCounterType.NumberOfItems32));

            PerformanceCounterCategory.Create("My Custom Counters", "Counters describing the usage of MyApp", PerformanceCounterCategoryType.SingleInstance, counters);
        }
    }



    /////////////////   Performance Counters Admin Controls     ///////////////////

    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            List<string> categories = new List<string>();

            foreach (PerformanceCounterCategory item in PerformanceCounterCategory.GetCategories())
            {
                if (item.CategoryName.StartsWith("ASP.NET") || item.CategoryName.StartsWith(".NET"))
                    categories.Add(item.CategoryName);
            }

            categories.Sort();

            ddlObjects.DataSource = categories;
            ddlObjects.DataBind();

            PerformanceCounterCategory category = new PerformanceCounterCategory(ddlObjects.SelectedItem.Text);

            DisplayCounters(category);
        }
    }

    private void DisplayCounters(PerformanceCounterCategory category)
    {
        DisplayInstances(category);

        List<string> counters = new List<string>();

        if (ddlInstances.Items.Count > 0)
        {
            foreach (PerformanceCounter pc in category.GetCounters(ddlInstances.Items[0].Value))
            {
                counters.Add(pc.CounterName);
            }
        }
        else
        {
            foreach (PerformanceCounter pc in category.GetCounters())
            {
                counters.Add(pc.CounterName);
            }
	
        }

        counters.Sort();

        ddlCounters.DataSource=counters;
        ddlCounters.DataBind();
    }

    private void DisplayInstances(PerformanceCounterCategory category)
    {
        List<string> instances = new List<string>();

        foreach (string item in category.GetInstanceNames())
        {
            instances.Add(item.ToString());
        }

        instances.Sort();

        ddlInstances.DataSource = instances;
        ddlInstances.DataBind();


    }

    protected void ddlObjects_SelectedIndexChanged(object sender, EventArgs e)
    {
        PerformanceCounterCategory category = new PerformanceCounterCategory(ddlObjects.SelectedItem.Text);

        ddlCounters.Items.Clear();
        ddlInstances.Items.Clear();

        DisplayCounters(category);
    }

    protected void ddlInstances_SelectedIndexChanged(object sender, EventArgs e)
    {
        ShowValue();
    }

    protected void lbFetchValue_Click(object sender, EventArgs e)
    {
        ShowValue();
    }

    private void ShowValue()
    {
        PerformanceCounter pc;
        if (ddlInstances.Items.Count > 0)
        {
            pc = new PerformanceCounter(ddlObjects.SelectedItem.Text,
                ddlCounters.SelectedItem.Text, ddlInstances.SelectedItem.Text);
        }
        else
        {
            pc = new PerformanceCounter(ddlObjects.SelectedItem.Text,
                ddlCounters.SelectedItem.Text);
        }

        lblValue.Text = pc.NextValue().ToString();
    }
 
    

}
